@@ -1,6 +1,6 @@
 typedef struct rc6_instance {
 	word32 l_key[44];
 } rc6_key;
-void _mcrypt_set_key(rc6_key* key, const word32* in_key, const word32 key_len);
+int _mcrypt_set_key(rc6_key* key, const word32* in_key, const word32 key_len);
 void _mcrypt_encrypt(rc6_key* key, word32* _blk);
 void _mcrypt_decrypt(rc6_key* key, word32 *_blk);
